use serde::{Deserialize, Serialize};
use storage::Storage;

mod storage;
pub mod repos;

#[derive(Debug, Serialize, Deserialize)]
pub struct Config {
    #[serde(default)]
    pub build_by_default: bool,
    #[serde(default)]
    pub tmp_dir: Option<String>,
    #[serde(default)]
    pub storage: Storage
}

impl Default for Config {
    fn default() -> Config {
        Config {
            build_by_default: false,
            tmp_dir: Some(String::from("/tmp/pkgr")),
            storage: Storage::default()
        }
    }
}

impl Config {
    pub fn from_path(path: &str) -> Result<Config, String> {
        match std::fs::read_to_string(path) {
            Ok(s) => match toml::from_str(&s) {
                Ok(c) => Ok(c),
                Err(e) => Err(format!("failed to parse config: {}", e)),
            },
            Err(e) => Err(format!("failed to read config: {}", e)),
        }
    }
}
